Changeset: 531c157a1c42 for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=531c157a1c42
Modified Files:
        gdk/Makefile.ag
        gdk/gdk.h
        gdk/gdk_private.h
Branch: leftmart
Log Message:

Simpler name for the index is OID order.


diffs (93 lines):

diff --git a/gdk/Makefile.ag b/gdk/Makefile.ag
--- a/gdk/Makefile.ag
+++ b/gdk/Makefile.ag
@@ -27,7 +27,7 @@ lib_gdk = {
                gdk_calc.c gdk_calc.h gdk_calc_compare.h gdk_calc_private.h \
                gdk_aggr.c gdk_group.c gdk_mapreduce.c gdk_mapreduce.h \
                gdk_imprints.c gdk_imprints.h \
-               gdk_arngment.c \
+               gdk_orderindex.c \
                gdk_join.c gdk_join_legacy.c \
                gdk_unique.c \
                gdk_firstn.c \
diff --git a/gdk/gdk_private.h b/gdk/gdk_private.h
--- a/gdk/gdk_private.h
+++ b/gdk/gdk_private.h
@@ -222,6 +222,7 @@ struct Imprints {
 };
 
 struct Arngment {
+       int flags;
        Heap *arngment;
 };
 
_______________________________________________
checkin-list mailing list
checkin-list@monetdb.org
https://www.monetdb.org/mailman/listinfo/checkin-list

Reply via email to
diff --git a/gdk/gdk.h b/gdk/gdk.h
--- a/gdk/gdk.h
+++ b/gdk/gdk.h
@@ -675,7 +675,7 @@ typedef struct {
 } Hash;
 
 typedef struct Imprints Imprints;
-typedef struct Arngment Arngment;
+typedef struct Order Order;
 
 
 /*
@@ -798,7 +798,7 @@ gdk_export int VALisnil(const ValRecord 
  *           Heap   *hheap;           // heap for varsized head values
  *           Hash   *hhash;           // linear chained hash table on head
  *           Imprints *himprints;     // column imprints index on head
  *           Arngment *harngment;     // oid index arrangement on head
  *           // Tail properties
  *           int    ttype;            // Tail type number
  *           str    tident;           // name for tail column
@@ -812,7 +812,7 @@ gdk_export int VALisnil(const ValRecord 
  *           Heap   *theap;           // heap for varsized tail values
  *           Hash   *thash;           // linear chained hash table on tail
  *           Imprints *timprints;     // column imprints index on tail
  *           Arngment *tarngment;     // oid index arrangement on tail
  *  } BAT;
  * @end verbatim
  *
@@ -892,7 +892,7 @@ typedef struct {
        Heap *vheap;            /* space for the varsized data. */
        Hash *hash;             /* hash table */
        Imprints *imprints;     /* column imprints index */
-       Arngment *arngment;     /* oid index arrangement */
+       Order *order;   /* order oid index */
 
        PROPrec *props;         /* list of dynamic properties stored in the bat 
descriptor */
 } COLrec;
@@ -2074,7 +2074,7 @@ gdk_export oid OIDnew(oid inc);
  * @end multitable
  *
  * The current BAT implementation supports three search accelerators:
  * hashing, imprints, and oid arrangement.
  *
  * The routine BAThash makes sure that a hash accelerator on the tail of the
  * BAT exists. GDK_FAIL is returned upon failure to create the supportive
@@ -2099,7 +2099,7 @@ gdk_export gdk_return BATimprints(BAT *b
 gdk_export lng IMPSimprintsize(BAT *b);
 
 /*
  * @- OID index arrangement
  *
  * @multitable @columnfractions 0.08 0.7
  * @item BAT*
@@ -2107,10 +2107,10 @@ gdk_export lng IMPSimprintsize(BAT *b);
  *  BAT 
  * @end multitable
  *
  * The oid index arrangement.
  *
  */
-gdk_export gdk_return ARNGindex(BAT *b, BAT *a);
+gdk_export gdk_return ORDERindex(BAT *b, BAT *order);
 
 /*
  * @- Multilevel Storage Modes
@@ -798,7 +798,7 @@ gdk_export int VALisnil(const ValRecord 
  *           Hash   *hhash;           // linear chained hash table on head
  *           Imprints *himprints;     // column imprints index on head
- *           Arngment *harngment;     // oid index arrangement on head
+ *           Order    *horder;        // order oid index on head
  *           // Tail properties
  *           int    ttype;            // Tail type number
@@ -812,7 +812,7 @@ gdk_export int VALisnil(const ValRecord 
  *           Hash   *thash;           // linear chained hash table on tail
  *           Imprints *timprints;     // column imprints index on tail
- *           Arngment *tarngment;     // oid index arrangement on tail
+ *           Order *torder;           // order oid index on tail
  *  } BAT;
  * @end verbatim
@@ -2074,7 +2074,7 @@ gdk_export oid OIDnew(oid inc);
  *
  * The current BAT implementation supports three search accelerators:
- * hashing, imprints, and oid arrangement.
+ * hashing, imprints, and oid order.
  *
  * The routine BAThash makes sure that a hash accelerator on the tail of the
@@ -2099,7 +2099,7 @@ gdk_export gdk_return BATimprints(BAT *b
 
 /*
- * @- OID index arrangement
+ * @- OID index order
  *
  * @multitable @columnfractions 0.08 0.7
@@ -2107,10 +2107,10 @@ gdk_export lng IMPSimprintsize(BAT *b);
  * @end multitable
  *
- * The oid index arrangement.
+ * The oid index order.
  *
  */